from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NestedField(_message.Message):
    __slots__ = ("field_name", "series_id", "int_values", "string_values", "double_values", "fields", "long_values", "is_list")
    FIELD_NAME_FIELD_NUMBER: _ClassVar[int]
    SERIES_ID_FIELD_NUMBER: _ClassVar[int]
    INT_VALUES_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUES_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUES_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    LONG_VALUES_FIELD_NUMBER: _ClassVar[int]
    IS_LIST_FIELD_NUMBER: _ClassVar[int]
    field_name: str
    series_id: int
    int_values: _containers.RepeatedScalarFieldContainer[int]
    string_values: _containers.RepeatedScalarFieldContainer[str]
    double_values: _containers.RepeatedScalarFieldContainer[float]
    fields: _containers.RepeatedCompositeFieldContainer[NestedField]
    long_values: _containers.RepeatedScalarFieldContainer[int]
    is_list: bool
    def __init__(self, field_name: _Optional[str] = ..., series_id: _Optional[int] = ..., int_values: _Optional[_Iterable[int]] = ..., string_values: _Optional[_Iterable[str]] = ..., double_values: _Optional[_Iterable[float]] = ..., fields: _Optional[_Iterable[_Union[NestedField, _Mapping]]] = ..., long_values: _Optional[_Iterable[int]] = ..., is_list: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: agent_message.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x61gent_message.proto\x12\rcommunication\"\xb7\x01\n\rProtoDataItem\x12\x14\n\x0c\x64\x61ta_type_id\x18\x01 \x02(\x05\x12\x13\n\x0b\x62ool_values\x18\x02 \x03(\x08\x12\x16\n\nint_values\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x17\n\x0blong_values\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x18\n\x0c\x66loat_values\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x19\n\rdouble_values\x18\x06 \x03(\x01\x42\x02\x10\x01\x12\x15\n\rstring_values\x18\x07 \x03(\t\"\x80\x02\n\nNestedItem\x12\x14\n\x0c\x64\x61ta_type_id\x18\x01 \x02(\x05\x12\x13\n\x0b\x62ool_values\x18\x02 \x03(\x08\x12\x16\n\nint_values\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x17\n\x0blong_values\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x18\n\x0c\x66loat_values\x18\x05 \x03(\x02\x42\x02\x10\x01\x12\x19\n\rdouble_values\x18\x06 \x03(\x01\x42\x02\x10\x01\x12\x15\n\rstring_values\x18\x07 \x03(\t\x12\x1b\n\x0ftime_series_ids\x18\x08 \x03(\x05\x42\x02\x10\x01\x12-\n\ncomponents\x18\t \x03(\x0b\x32\x19.communication.NestedItem\"\x99\x01\n\x0cProtoMessage\x12\x11\n\tsender_id\x18\x01 \x02(\x03\x12\x13\n\x0breceiver_id\x18\x02 \x02(\x03\x12\x30\n\ndata_items\x18\x03 \x03(\x0b\x32\x1c.communication.ProtoDataItem\x12/\n\x0cnested_items\x18\x04 \x03(\x0b\x32\x19.communication.NestedItemB$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05\x41gent')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agent_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Agent'
  _globals['_PROTODATAITEM'].fields_by_name['int_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['int_values']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM'].fields_by_name['long_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['long_values']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM'].fields_by_name['float_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['float_values']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM'].fields_by_name['double_values']._options = None
  _globals['_PROTODATAITEM'].fields_by_name['double_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['int_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['int_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['long_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['long_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['float_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['float_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['double_values']._options = None
  _globals['_NESTEDITEM'].fields_by_name['double_values']._serialized_options = b'\020\001'
  _globals['_NESTEDITEM'].fields_by_name['time_series_ids']._options = None
  _globals['_NESTEDITEM'].fields_by_name['time_series_ids']._serialized_options = b'\020\001'
  _globals['_PROTODATAITEM']._serialized_start=39
  _globals['_PROTODATAITEM']._serialized_end=222
  _globals['_NESTEDITEM']._serialized_start=225
  _globals['_NESTEDITEM']._serialized_end=481
  _globals['_PROTOMESSAGE']._serialized_start=484
  _globals['_PROTOMESSAGE']._serialized_end=637
# @@protoc_insertion_point(module_scope)



from fameprotobuf import field_pb2 as _field_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProtoContract(_message.Message):
    __slots__ = ("sender_id", "receiver_id", "product_name", "first_delivery_time", "delivery_interval_in_steps", "expiration_time", "fields", "metadata")
    SENDER_ID_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_ID_FIELD_NUMBER: _ClassVar[int]
    PRODUCT_NAME_FIELD_NUMBER: _ClassVar[int]
    FIRST_DELIVERY_TIME_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_INTERVAL_IN_STEPS_FIELD_NUMBER: _ClassVar[int]
    EXPIRATION_TIME_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    sender_id: int
    receiver_id: int
    product_name: str
    first_delivery_time: int
    delivery_interval_in_steps: int
    expiration_time: int
    fields: _containers.RepeatedCompositeFieldContainer[_field_pb2.NestedField]
    metadata: str
    def __init__(self, sender_id: _Optional[int] = ..., receiver_id: _Optional[int] = ..., product_name: _Optional[str] = ..., first_delivery_time: _Optional[int] = ..., delivery_interval_in_steps: _Optional[int] = ..., expiration_time: _Optional[int] = ..., fields: _Optional[_Iterable[_Union[_field_pb2.NestedField, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModelData(_message.Message):
    __slots__ = ("name", "version", "package_definition")
    class JavaPackages(_message.Message):
        __slots__ = ("agents", "data_items", "portables")
        AGENTS_FIELD_NUMBER: _ClassVar[int]
        DATA_ITEMS_FIELD_NUMBER: _ClassVar[int]
        PORTABLES_FIELD_NUMBER: _ClassVar[int]
        agents: _containers.RepeatedScalarFieldContainer[str]
        data_items: _containers.RepeatedScalarFieldContainer[str]
        portables: _containers.RepeatedScalarFieldContainer[str]
        def __init__(self, agents: _Optional[_Iterable[str]] = ..., data_items: _Optional[_Iterable[str]] = ..., portables: _Optional[_Iterable[str]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    PACKAGE_DEFINITION_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    package_definition: ModelData.JavaPackages
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., package_definition: _Optional[_Union[ModelData.JavaPackages, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ProtoDataItem(_message.Message):
    __slots__ = ("data_type_id", "bool_values", "int_values", "long_values", "float_values", "double_values", "string_values")
    DATA_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUES_FIELD_NUMBER: _ClassVar[int]
    INT_VALUES_FIELD_NUMBER: _ClassVar[int]
    LONG_VALUES_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUES_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUES_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUES_FIELD_NUMBER: _ClassVar[int]
    data_type_id: int
    bool_values: _containers.RepeatedScalarFieldContainer[bool]
    int_values: _containers.RepeatedScalarFieldContainer[int]
    long_values: _containers.RepeatedScalarFieldContainer[int]
    float_values: _containers.RepeatedScalarFieldContainer[float]
    double_values: _containers.RepeatedScalarFieldContainer[float]
    string_values: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, data_type_id: _Optional[int] = ..., bool_values: _Optional[_Iterable[bool]] = ..., int_values: _Optional[_Iterable[int]] = ..., long_values: _Optional[_Iterable[int]] = ..., float_values: _Optional[_Iterable[float]] = ..., double_values: _Optional[_Iterable[float]] = ..., string_values: _Optional[_Iterable[str]] = ...) -> None: ...

class NestedItem(_message.Message):
    __slots__ = ("data_type_id", "bool_values", "int_values", "long_values", "float_values", "double_values", "string_values", "time_series_ids", "components")
    DATA_TYPE_ID_FIELD_NUMBER: _ClassVar[int]
    BOOL_VALUES_FIELD_NUMBER: _ClassVar[int]
    INT_VALUES_FIELD_NUMBER: _ClassVar[int]
    LONG_VALUES_FIELD_NUMBER: _ClassVar[int]
    FLOAT_VALUES_FIELD_NUMBER: _ClassVar[int]
    DOUBLE_VALUES_FIELD_NUMBER: _ClassVar[int]
    STRING_VALUES_FIELD_NUMBER: _ClassVar[int]
    TIME_SERIES_IDS_FIELD_NUMBER: _ClassVar[int]
    COMPONENTS_FIELD_NUMBER: _ClassVar[int]
    data_type_id: int
    bool_values: _containers.RepeatedScalarFieldContainer[bool]
    int_values: _containers.RepeatedScalarFieldContainer[int]
    long_values: _containers.RepeatedScalarFieldContainer[int]
    float_values: _containers.RepeatedScalarFieldContainer[float]
    double_values: _containers.RepeatedScalarFieldContainer[float]
    string_values: _containers.RepeatedScalarFieldContainer[str]
    time_series_ids: _containers.RepeatedScalarFieldContainer[int]
    components: _containers.RepeatedCompositeFieldContainer[NestedItem]
    def __init__(self, data_type_id: _Optional[int] = ..., bool_values: _Optional[_Iterable[bool]] = ..., int_values: _Optional[_Iterable[int]] = ..., long_values: _Optional[_Iterable[int]] = ..., float_values: _Optional[_Iterable[float]] = ..., double_values: _Optional[_Iterable[float]] = ..., string_values: _Optional[_Iterable[str]] = ..., time_series_ids: _Optional[_Iterable[int]] = ..., components: _Optional[_Iterable[_Union[NestedItem, _Mapping]]] = ...) -> None: ...

class ProtoMessage(_message.Message):
    __slots__ = ("sender_id", "receiver_id", "data_items", "nested_items")
    SENDER_ID_FIELD_NUMBER: _ClassVar[int]
    RECEIVER_ID_FIELD_NUMBER: _ClassVar[int]
    DATA_ITEMS_FIELD_NUMBER: _ClassVar[int]
    NESTED_ITEMS_FIELD_NUMBER: _ClassVar[int]
    sender_id: int
    receiver_id: int
    data_items: _containers.RepeatedCompositeFieldContainer[ProtoDataItem]
    nested_items: _containers.RepeatedCompositeFieldContainer[NestedItem]
    def __init__(self, sender_id: _Optional[int] = ..., receiver_id: _Optional[int] = ..., data_items: _Optional[_Iterable[_Union[ProtoDataItem, _Mapping]]] = ..., nested_items: _Optional[_Iterable[_Union[NestedItem, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: services.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eservices.proto\x12\rcommunication\"\"\n\rScheduledTime\x12\x11\n\ttime_step\x18\x01 \x02(\x03\"\x1f\n\rWarmUpMessage\x12\x0e\n\x06needed\x18\x01 \x02(\x08\"\xda\x04\n\x06Output\x12\x34\n\x0b\x61gent_types\x18\x01 \x03(\x0b\x32\x1f.communication.Output.AgentType\x12,\n\x06series\x18\x02 \x03(\x0b\x32\x1c.communication.Output.Series\x1a\x9a\x01\n\tAgentType\x12\x12\n\nclass_name\x18\x01 \x02(\t\x12\x35\n\x06\x66ields\x18\x02 \x03(\x0b\x32%.communication.Output.AgentType.Field\x1a\x42\n\x05\x46ield\x12\x10\n\x08\x66ield_id\x18\x01 \x02(\x05\x12\x12\n\nfield_name\x18\x02 \x02(\t\x12\x13\n\x0bindex_names\x18\x03 \x03(\t\x1a\xce\x02\n\x06Series\x12\x12\n\nclass_name\x18\x01 \x02(\t\x12\x10\n\x08\x61gent_id\x18\x02 \x02(\x03\x12\x30\n\x05lines\x18\x03 \x03(\x0b\x32!.communication.Output.Series.Line\x1a\xeb\x01\n\x04Line\x12\x11\n\ttime_step\x18\x01 \x02(\x03\x12\x39\n\x07\x63olumns\x18\x02 \x03(\x0b\x32(.communication.Output.Series.Line.Column\x1a\x94\x01\n\x06\x43olumn\x12\x10\n\x08\x66ield_id\x18\x01 \x02(\x05\x12\r\n\x05value\x18\x02 \x01(\x01\x12=\n\x07\x65ntries\x18\x03 \x03(\x0b\x32,.communication.Output.Series.Line.Column.Map\x1a*\n\x03Map\x12\x14\n\x0cindex_values\x18\x01 \x03(\t\x12\r\n\x05value\x18\x02 \x02(\t\"8\n\x0b\x41\x64\x64ressBook\x12\x12\n\nprocess_id\x18\x01 \x02(\x05\x12\x15\n\tagent_ids\x18\x02 \x03(\x03\x42\x02\x10\x01\x42\'\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x08Services')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'services_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\010Services'
  _globals['_ADDRESSBOOK'].fields_by_name['agent_ids']._options = None
  _globals['_ADDRESSBOOK'].fields_by_name['agent_ids']._serialized_options = b'\020\001'
  _globals['_SCHEDULEDTIME']._serialized_start=33
  _globals['_SCHEDULEDTIME']._serialized_end=67
  _globals['_WARMUPMESSAGE']._serialized_start=69
  _globals['_WARMUPMESSAGE']._serialized_end=100
  _globals['_OUTPUT']._serialized_start=103
  _globals['_OUTPUT']._serialized_end=705
  _globals['_OUTPUT_AGENTTYPE']._serialized_start=214
  _globals['_OUTPUT_AGENTTYPE']._serialized_end=368
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_start=302
  _globals['_OUTPUT_AGENTTYPE_FIELD']._serialized_end=368
  _globals['_OUTPUT_SERIES']._serialized_start=371
  _globals['_OUTPUT_SERIES']._serialized_end=705
  _globals['_OUTPUT_SERIES_LINE']._serialized_start=470
  _globals['_OUTPUT_SERIES_LINE']._serialized_end=705
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_start=557
  _globals['_OUTPUT_SERIES_LINE_COLUMN']._serialized_end=705
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_start=663
  _globals['_OUTPUT_SERIES_LINE_COLUMN_MAP']._serialized_end=705
  _globals['_ADDRESSBOOK']._serialized_start=707
  _globals['_ADDRESSBOOK']._serialized_end=763
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: field.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x66ield.proto\x12\x08iobinary\"\xd6\x01\n\x0bNestedField\x12\x12\n\nfield_name\x18\x01 \x02(\t\x12\x11\n\tseries_id\x18\x02 \x01(\x05\x12\x16\n\nint_values\x18\x03 \x03(\x05\x42\x02\x10\x01\x12\x15\n\rstring_values\x18\x04 \x03(\t\x12\x19\n\rdouble_values\x18\x05 \x03(\x01\x42\x02\x10\x01\x12%\n\x06\x66ields\x18\x06 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x17\n\x0blong_values\x18\x07 \x03(\x03\x42\x02\x10\x01\x12\x16\n\x07is_list\x18\x08 \x01(\x08:\x05\x66\x61lseB$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05\x46ield')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'field_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Field'
  _globals['_NESTEDFIELD'].fields_by_name['int_values']._options = None
  _globals['_NESTEDFIELD'].fields_by_name['int_values']._serialized_options = b'\020\001'
  _globals['_NESTEDFIELD'].fields_by_name['double_values']._options = None
  _globals['_NESTEDFIELD'].fields_by_name['double_values']._serialized_options = b'\020\001'
  _globals['_NESTEDFIELD'].fields_by_name['long_values']._options = None
  _globals['_NESTEDFIELD'].fields_by_name['long_values']._serialized_options = b'\020\001'
  _globals['_NESTEDFIELD']._serialized_start=26
  _globals['_NESTEDFIELD']._serialized_end=240
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data_storage.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import services_pb2 as services__pb2
from fameprotobuf import input_file_pb2 as input__file__pb2
from fameprotobuf import execution_data_pb2 as execution__data__pb2
from fameprotobuf import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x64\x61ta_storage.proto\x12\x08iobinary\x1a\x0eservices.proto\x1a\x10input_file.proto\x1a\x14\x65xecution_data.proto\x1a\x0bmodel.proto\"\xa5\x01\n\x0b\x44\x61taStorage\x12\"\n\x05input\x18\x01 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x02 \x01(\x0b\x32\x15.communication.Output\x12*\n\texecution\x18\x03 \x01(\x0b\x32\x17.iobinary.ExecutionData\x12\x1f\n\x05model\x18\x04 \x01(\x0b\x32\x10.model.ModelDataB&\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x07Storage')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'data_storage_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\007Storage'
  _globals['_DATASTORAGE']._serialized_start=102
  _globals['_DATASTORAGE']._serialized_end=267
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
# Protobuf Python Version: 4.25.4
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x05model\"\xac\x01\n\tModelData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x39\n\x12package_definition\x18\x03 \x01(\x0b\x32\x1d.model.ModelData.JavaPackages\x1a\x45\n\x0cJavaPackages\x12\x0e\n\x06\x61gents\x18\x01 \x03(\t\x12\x12\n\ndata_items\x18\x02 \x03(\t\x12\x11\n\tportables\x18\x03 \x03(\tB$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Model')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Model'
  _globals['_MODELDATA']._serialized_start=23
  _globals['_MODELDATA']._serialized_end=195
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_start=126
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_end=195
# @@protoc_insertion_point(module_scope)



from fameprotobuf import services_pb2 as _services_pb2
from fameprotobuf import input_file_pb2 as _input_file_pb2
from fameprotobuf import execution_data_pb2 as _execution_data_pb2
from fameprotobuf import model_pb2 as _model_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataStorage(_message.Message):
    __slots__ = ("input", "output", "execution", "model")
    INPUT_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    input: _input_file_pb2.InputData
    output: _services_pb2.Output
    execution: _execution_data_pb2.ExecutionData
    model: _model_pb2.ModelData
    def __init__(self, input: _Optional[_Union[_input_file_pb2.InputData, _Mapping]] = ..., output: _Optional[_Union[_services_pb2.Output, _Mapping]] = ..., execution: _Optional[_Union[_execution_data_pb2.ExecutionData, _Mapping]] = ..., model: _Optional[_Union[_model_pb2.ModelData, _Mapping]] = ...) -> None: ...
